# -*- coding: utf-8 -*-
# Actions pour l'interface d'admin

from django.http import HttpResponse


def generate_mailto(modeladmin, request, queryset):
    emails = queryset.exclude(email="").values_list("email", flat=True)
    emails_mailto = "mailto:contact@apes.org, ?bcc=%s" % (",".join(emails))
    emails_display = "%s" % ("<br />".join(emails))
    return HttpResponse(
        "<head><script type='text/javascript'>\n"
        "function redirect () { setTimeout('go_now()',1000); }\n"
        "function go_now () { window.location.href = '%s'; }\n"
        "</script></head>\n"
        "<body onLoad='redirect()'>\n"
        "Envoi à:<br /><a href='%s'>%s</a>\n"
        "</body>" % (emails_mailto, emails_mailto, emails_display)
    )


generate_mailto.short_description = "Envoyer un courriel"


def _fmt(value):
    """
    Fonction utilitaire utilisée pour les exports CSV.
    """
    if value is False:
        return "FAUX"
    if value is True:
        return "VRAI"
    if not value:
        return ""
    return '"%s"' % value


def export_personne_csv(modeladmin, request, queryset):
    """
    Exporte les objets personne sélectionnés en CSV.
    """
    nom_colonnes = (
        "nom",
        "prenom",
        "adresse",
        "code postal",
        "ville",
        "telephone1",
        "telephone2",
        "email",
        "abonné",
        "adhérent",
        "SOL",
        "Journaliste",
        "territoires",
        "échéance d'adhésion",
        "échéance d'abonnement",
        "college",
    )

    SEP = ";"
    csv = SEP.join([_fmt(x) for x in nom_colonnes]) + "\n"

    for p in queryset.all():
        csv += (
            SEP.join(
                [
                    _fmt(x)
                    for x in [
                        p.nom,
                        p.prenom,
                        p.adresse,
                        p.code_postal,
                        p.ville,
                        p.telephone1,
                        p.telephone2,
                        p.email,
                    ]
                ]
            )
            + SEP
        )

        csv += _fmt(p.abonne) + SEP
        csv += _fmt(p.adherent) + SEP
        csv += _fmt(p.sol) + SEP
        csv += _fmt(p.journaliste) + SEP
        csv += ", ".join([str(x) for x in p.territoires.all()]) + SEP
        csv += _fmt(p.echeance_adhesion(htmlized=False)) + SEP
        csv += _fmt(p.echeance_abonnement(htmlized=False)) + SEP
        csv += _fmt(p.get_college()) + SEP
        csv += "\r\n"

    response = HttpResponse(csv, content_type="text/csv")
    response[
        "Content-Disposition"
    ] = "attachment; filename=export_personne_bdd.csv"
    return response


export_personne_csv.short_description = "Exporter les personnes en CSV"


def export_structure_csv(modeladmin, request, queryset):
    """
    Exporte les objets structure sélectionnés en CSV.
    """
    nom_colonnes = (
        "nom",
        "adresse",
        "code postal",
        "ville",
        "telephone1",
        "telephone2",
        "email",
        "site",
        "territoires",
        "domaines_activite_txt",
        "statut juridique",
        "nb_salaries",
        "mission",
        "demarche_progres",
        "environnement",
        "emploi",
        "BDIS Pro",
        "collectifs_acteurs",
        "sol",
        "institutionnel",
        "journaliste",
        "contact",
        "echeance_adhesion",
        "echeance_abonnement",
        "college",
    )

    SEP = ";"
    csv = SEP.join([_fmt(x) for x in nom_colonnes]) + "\r\n"
    for s in queryset.all():
        csv += (
            SEP.join(
                [
                    _fmt(x)
                    for x in [
                        s.nom,
                        s.adresse,
                        s.code_postal,
                        s.ville,
                        s.telephone1,
                        s.telephone2,
                        s.email,
                        s.site,
                    ]
                ]
            )
            + SEP
        )
        csv += ", ".join([str(x) for x in s.territoires.all()]) + SEP
        csv += _fmt(s.domaines_activite_txt) + SEP
        if s.statut_juridique:
            csv += _fmt(s.statut_juridique.libelle) + SEP
        else:
            csv += SEP
        csv += (
            SEP.join(
                [
                    _fmt(x)
                    for x in [
                        s.nb_salaries,
                        s.mission,
                        s.demarche_progres,
                        s.demarche_progres_environnement,
                        s.demarche_progres_emploi,
                        s.marche_citoyen,
                        s.collectifs_acteurs,
                        s.sol,
                        s.institutionnel,
                        s.journaliste,
                        s.autres_contacts,
                    ]
                ]
            )
            + SEP
        )
        csv += _fmt(s.echeance_adhesion(htmlized=False)) + SEP
        csv += _fmt(s.echeance_abonnement(htmlized=False)) + SEP
        csv += _fmt(s.get_college()) + SEP
        csv += "\r\n"
    response = HttpResponse(csv, content_type="text/csv")
    response[
        "Content-Disposition"
    ] = "attachment; filename=export_structure_bdd.csv"
    return response


export_structure_csv.short_description = "Exporter les structures en CSV"

# EOF
