# -*- coding: utf-8 -*-
# Vues spécifiques pour l'interface d'admin

import datetime
import tempfile

from django.conf.urls import re_path
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import get_object_or_404, redirect, render
from django.template.loader import render_to_string
from django.views.generic import UpdateView

from weasyprint import HTML

from grapes.bdd.forms import (
    AbonnementForm,
    AdhesionForm,
    AdhesionPersonneForm,
    ModePaiementAbonnementForm,
    ModePaiementAdhesionForm,
)
from grapes.bdd.models import (
    Abonnement,
    Adhesion,
    ModePaiementAbonnement,
    ModePaiementAdhesion,
)


class MyUpdateView(UpdateView):
    extra_context = None

    def get_context_data(self, **kwargs):
        ret = super(MyUpdateView, self).get_context_data(**kwargs)
        if self.extra_context is not None:  # pragma: no cover
            ret.update(self.extra_context)
        return ret


##
# Affiliations
##


def ps_get_urls(self):
    urls = super(self.__class__, self).get_urls()
    my_urls = [
        re_path(
            r"^(?P<object_id>\d+)/change/affiliation/$",
            self.admin_site.admin_view(self.affiliation_detail),
        ),
        re_path(
            r"^(?P<object_id>\d+)/change/affiliation/abonnement/create/$",
            self.admin_site.admin_view(self.abonnement_create),
        ),
        re_path(
            r"^(?P<object_id>\d+)/change/affiliation/adhesion/create/$",
            self.admin_site.admin_view(self.adhesion_create),
        ),
        re_path(
            r"^\d+/change/affiliation/abonnement/(?P<pk>\d+)/$",
            self.admin_site.admin_view(
                MyUpdateView.as_view(
                    form_class=AbonnementForm,
                    success_url="../../",
                    model=Abonnement,
                    extra_context={"title": "Abonnement"},
                )
            ),
        ),
        re_path(
            r"^\d+/change/affiliation/adhesion/(?P<object_id>\d+)/$",
            self.admin_site.admin_view(self.adhesion_update),
        ),
        re_path(
            r"^(?P<object_id>\d+)/change/affiliation/"
            "abonnement/paiement/create/$",
            self.admin_site.admin_view(self.abonnement_paiement_create),
        ),
        re_path(
            r"^(?P<object_id>\d+)/change/affiliation/"
            "adhesion/paiement/create/$",
            self.admin_site.admin_view(self.adhesion_paiement_create),
        ),
        re_path(
            r"^\d+/change/affiliation/abonnement/paiement/(?P<pk>\d+)/$",
            self.admin_site.admin_view(
                MyUpdateView.as_view(
                    form_class=ModePaiementAbonnementForm,
                    success_url="../../../",
                    model=ModePaiementAbonnement,
                    extra_context={"title": "Paiement abonnement"},
                )
            ),
        ),
        re_path(
            r"^\d+/change/affiliation/adhesion/paiement/(?P<pk>\d+)/$",
            self.admin_site.admin_view(
                MyUpdateView.as_view(
                    form_class=ModePaiementAdhesionForm,
                    success_url="../../../",
                    model=ModePaiementAdhesion,
                    extra_context={"title": "Paiement adhésion"},
                )
            ),
        ),
        re_path(
            r'^\d+/imprime-facture-adhesion/(?P<pk>\d+)/$',
            self.admin_site.admin_view(
                print_invoice_adhesion,
            ),
            name='imprime-facture-adhesion',
        ),
    ]
    return my_urls + urls


def abonnement_create(self, request, object_id):
    """
    Go to object's adhesion, or create one if there's none yet
    """
    object = get_object_or_404(self.model, pk=object_id)
    affiliation = object.affiliation_set.get()
    try:
        abonnement = affiliation.abonnement
    except Abonnement.DoesNotExist:
        abonnement = Abonnement(affiliation=affiliation)
        abonnement.save()
    return HttpResponseRedirect("../%d/" % abonnement.id)


def adhesion_create(self, request, object_id):
    """
    s/adhesion/abonnement/ adhesion_create
    """
    object = get_object_or_404(self.model, pk=object_id)
    affiliation = object.affiliation_set.get()
    try:
        adhesion = affiliation.adhesion
    except Adhesion.DoesNotExist:
        adhesion = Adhesion(affiliation=affiliation)
        adhesion.save()
    return HttpResponseRedirect("../%d/" % adhesion.id)


def abonnement_paiement_create(self, request, object_id):
    """
    Go to object's paiement, or create one if there's none yet
    """
    object = get_object_or_404(self.model, pk=object_id)
    affiliation = object.affiliation_set.get()
    abonnement = affiliation.abonnement
    if abonnement.paiement is None:
        paiement = ModePaiementAbonnement()
        paiement.save()
        abonnement.paiement = paiement
        abonnement.save()
    return HttpResponseRedirect("../%d/" % abonnement.paiement.id)


def adhesion_paiement_create(self, request, object_id):
    """
    s/adhesion/abonnement/ adhesion_paiement
    """
    object = get_object_or_404(self.model, pk=object_id)

    affiliation = object.affiliation_set.get()
    adhesion = affiliation.adhesion
    if adhesion.paiement is None:
        paiement = ModePaiementAdhesion()
        paiement.save()
        adhesion.paiement = paiement
        adhesion.save()
    return HttpResponseRedirect("../%d/" % adhesion.paiement.id)


def adhesion_update(self, request, object_id):
    """
    Formulaire d'abonnement
    """
    adhesion = Adhesion.objects.get(pk=object_id)
    if request.method == "POST":
        if adhesion.affiliation.structure is not None:
            form = AdhesionForm(request.POST, instance=adhesion)
        elif adhesion.affiliation.personne is not None:
            form = AdhesionPersonneForm(request.POST, instance=adhesion)
        if form.is_valid():
            if adhesion.affiliation.structure is not None:
                form.save()
            elif adhesion.affiliation.personne is not None:
                fr = form.save(commit=False)
                fr.college = "A"
                fr.save()
            return HttpResponseRedirect("../../")
    else:
        if adhesion.affiliation.structure is not None:
            form = AdhesionForm(instance=adhesion)
            college = None
        elif adhesion.affiliation.personne is not None:
            form = AdhesionPersonneForm(instance=adhesion)
            college = "A"

    return render(
        request,
        "bdd/adhesion_add_new.html",
        {
            "title": adhesion,
            "college": college,
            "current_app": self.admin_site.name,  # useful?
            "form": form,
        },
    )


def print_invoice_adhesion(request, pk):
    """
    Facture d'adhésion
    """
    if not request.user.is_authenticated:
        return redirect(f"/gestion/login/?next={request.path}")
    Adh = Adhesion.objects.get(pk=pk)
    if Adh.affiliation.structure is not None:
        Adr = Adh.affiliation.structure.adresse_contact_etiquette
        Adr = (
            "À l'attention de l’agent comptable de<br/><strong>"
            + Adr.replace("\n", "</strong><br/>", 1).replace("\n", "<br/>")
        )
    elif Adh.affiliation.personne is not None:
        Adr = Adh.affiliation.personne.adresse_complete
        Adr = "<strong>" + Adr.replace("\n", "</strong><br/>", 1).replace(
            "\n", "<br/>"
        )
    context = {
        'adresse': Adr,
        'college': Adh.college,
        'montant': Adh.paiement.montant,
        'nom': Adh.nom_associe,
        'num_adhesion': Adh.id,
        'num_reglement': Adh.paiement.id,
        'date_jour': datetime.date.today(),
        'date_facturation': Adh.paiement.date_facturation,
        'date_reglement': Adh.paiement.date_reglement,
        'type_reglement': Adh.paiement.type.lower(),
    }

    # Rendu HTML vers PDF
    html_string = render_to_string('bdd/adhesion_invoice_print.html', context)
    html = HTML(string=html_string, base_url=request.build_absolute_uri())
    result = html.write_pdf()

    # Réponse HTTP
    response = HttpResponse(content_type='application/pdf;')
    response['Content-Disposition'] = 'attachement; filename=facture.pdf'
    response['Content-Transfer-Encoding'] = 'binary'
    with tempfile.NamedTemporaryFile(delete=True) as output:
        output.write(result)
        output.flush()
        output = open(output.name, 'rb')
        response.write(output.read())

    return response
