# -*- coding: utf-8 -*-
# Formulaires spécifiques pour l'interface d'admin

import datetime

from django import forms
from django.forms.utils import ErrorList, ValidationError

from grapes.bdd.models import (
    Abonnement,
    Adhesion,
    LienAvecAPES,
    LienWeb,
    ModePaiementAbonnement,
    ModePaiementAdhesion,
    Personne,
    Structure,
    Territoire,
)

CHOICES_COLLEGE = (
    ("A", "A"),
    ("B", "B"),
)


class AdhesionPaiementForm(forms.Form):
    college = forms.ChoiceField(choices=CHOICES_COLLEGE, label="Collège")
    # fonction_adherent = forms.CharField(
    #     required=False, label="Fonction de l'adhérent"
    # )
    date = forms.DateField(initial=datetime.datetime.today)
    # remarques = forms.CharField(required=False, widget=forms.Textarea)
    date_reglement = forms.DateField(label="Date de règlement", required=False)
    date_facturation = forms.DateField(
        label="Date facturation", required=False
    )
    type = forms.CharField(required=False, label="Type de paiement")
    montant = forms.IntegerField(required=False)

    def clean(self):
        if self.cleaned_data["montant"] and not self.cleaned_data["type"]:
            self._errors["type"] = ErrorList(
                ["Veuillez saisir le type de paiement"]
            )
            del self.cleaned_data["type"]
        return self.cleaned_data

    # def clean(self):
    #    if self.cleaned_data['montant'] and not self.cleaned_data['type']:
    #        raise forms.ValidationError("Veuillez saisir le type de paiement")


class AbonnementForm(forms.ModelForm):
    class Meta:
        model = Abonnement
        exclude = (
            "affiliation",
            "paiement",
        )


class AdhesionForm(forms.ModelForm):
    class Meta:
        model = Adhesion
        exclude = (
            "affiliation",
            "paiement",
        )

    # def __init__(self, *args, **kwargs):
    # dossier_choisi = kwargs.pop('dossier_choisi')
    #   super(AdhesionForm, self).__init__(*args, **kwargs)
    #   self.fields["college"]= forms.ChoiceField(
    #       choices = ((u'A',u'A'),
    #                )
    #       )


class AdhesionPersonneForm(forms.ModelForm):
    class Meta:
        model = Adhesion
        exclude = ("affiliation", "paiement", "college")


class TerritoireForm(forms.ModelForm):
    class Meta:
        model = Territoire
        exclude = ()


#   def clean(self):
#       slug = self.cleaned_data.get("slug")
#       if not slug:
#   parents = forms.ModelMultipleChoiceField(
#       Territoire.objects.filter(slug="france" OR slug="hauts-de-france"])
#   )


class LienAvecAPESForm(forms.ModelForm):
    class Meta:
        model = LienAvecAPES
        exclude = ()

    def clean(self):
        personne = self.cleaned_data.get("personne")
        structure = self.cleaned_data.get("structure")

        if personne and structure:
            raise ValidationError(
                "😵 Les champs « Personne » et « Structure » ne doivent pas "
                "être réglés en même temps."
            )


class LienWebForm(forms.ModelForm):
    class Meta:
        model = LienWeb
        exclude = ()

    def clean(self):
        personne = self.cleaned_data.get("personne")
        structure = self.cleaned_data.get("structure")

        if personne and structure:
            raise ValidationError(
                "😵 Les champs « Personne » et « Structure » ne doivent pas "
                " être réglés en même temps."
            )


class ModePaiementAbonnementForm(forms.ModelForm):
    class Meta:
        model = ModePaiementAbonnement
        exclude = ()


class ModePaiementAdhesionForm(forms.ModelForm):
    class Meta:
        model = ModePaiementAdhesion
        exclude = ()


class PersonneForm(forms.ModelForm):
    class Meta:
        model = Personne
        exclude = ()


class StructureForm(forms.ModelForm):
    class Meta:
        model = Structure
        widgets = {
            "demarche_progres": forms.widgets.CheckboxInput,
            "demarche_progres_environnement": forms.widgets.CheckboxInput,
            "demarche_progres_emploi": forms.widgets.CheckboxInput,
            "marche_citoyen": forms.widgets.CheckboxInput,
            "collectifs_acteurs": forms.widgets.CheckboxInput,
            "sol": forms.widgets.CheckboxInput,
            "institutionnel": forms.widgets.CheckboxInput,
            "journaliste": forms.widgets.CheckboxInput,
        }
        exclude = ()
