import csv

from django.core.exceptions import ValidationError
from django.core.management.base import BaseCommand
from django.utils.text import slugify
from grapes.bdd.models import Territoire


class Command(BaseCommand):
    """
    Moulinette pour l'import massif de territoires.
    """

    help = 'territory import utility. Takes a csv file.'
    requires_migrations_checks = True

    def add_arguments(self, parser):
        parser.add_argument(
            "--path",
            "-p",
            help="Specifies the path to the source csv file.",
        )

    def handle(self, *args, **options):
        if not options.get('path'):
            print(
                "Usage: python manage.py import_territoires source "
            )
            return
        else:
            path = options['path']

        # Ouverture du fichier
        try:
            f = open(path)
            file = csv.DictReader(f)
        except:  # noqa
            print(
                "Failed to open the file. Please make sure the path is correct "
                "and the file is properly formatted"
            )

        # Boucle de construction des objects
        added = 0
        updated = 0
        unchanged = 0
        warnings = []
        # Pour chaque ligne
        for line in file:
            # On extrait le mail s'il existe et est valide
            if line.get('NOM'):
                nom = line['NOM']
            else:
                # Sinon on passe à la ligne suivante
                warnings.append(line)
                continue
            # Si le territoire existe, on fait rien à part le comptabiliser.
            try:
                territoire = Territoire.objects.get(libelle=nom)
                print(f"\nFound existing territoire : {nom}")
                unchanged += 1
            # Sinon, on crée le territoire.
            except Territoire.DoesNotExist:
                Territoire.objects.create(libelle=nom,slug=slugify(nom))
                print(f"\nCreated territoire : {nom}")
                added += 1

        # On ferme le fichier
        f.close()

        print(f"\n{added} territoires added")
        print(f"{updated} territoires updated")
        print(f"{unchanged} territoires unchanged")
        if len(warnings) > 0:
            print(
                f"\nWARNING: {len(warnings)} territoire(s) have not been imported "
                "due to incorrect csv formatting."
            )
            print("Failed importing these lines :")
            for line in warnings:
                print(line)

