from django.conf import settings
from django.conf.urls import include, re_path, url

# Uncomment the next two lines to enable the admin:
from django.contrib import admin
from django.contrib.auth import models
from django.contrib.auth import views as auth_views
from django.urls import path
from django.views.generic import RedirectView

# Custom admin:
from grapes.bdd.admin import register_bdd_models
from grapes.bdd.admin_views import print_invoice_adhesion

admin.autodiscover()


class ApesAdmin(admin.AdminSite):
    pass


custom_admin_site = ApesAdmin()
register_bdd_models(custom_admin_site)

custom_admin_site.register(models.User)
custom_admin_site.register(models.Group)

urlpatterns = [
    path(
        'gestion/password_reset/',
        auth_views.PasswordResetView.as_view(),
        name='admin_password_reset',
    ),
    path(
        'gestion/password_reset/done/',
        auth_views.PasswordResetDoneView.as_view(),
        name='password_reset_done',
    ),
    path(
        'reset/<uidb64>/<token>/',
        auth_views.PasswordResetConfirmView.as_view(),
        name='password_reset_confirm',
    ),
    path(
        'reset/done/',
        auth_views.PasswordResetCompleteView.as_view(),
        name='password_reset_complete',
    ),
    re_path(
        r"^gestion/bdd/imprime-facture-adhesion/(?P<pk>\d+)/$",
        print_invoice_adhesion,
        name="imprime-facture-adhesion",
    ),
    re_path(r"^gestion/", custom_admin_site.urls),
    re_path(
        r"^accounts/login/",
        RedirectView.as_view(url="/gestion/login/", permanent=False)
    ),
    re_path(
        r"^$", RedirectView.as_view(url="/gestion/login/", permanent=False)
    ),
]

# Debug
if settings.DEBUG:
    from django.conf.urls.static import static
    from django.views import defaults as default_views

    # This allows the error pages to be debugged during development, just visit
    # these url in browser to see how these error pages look like.
    urlpatterns += [
        url(r'^400/$', default_views.bad_request,
            kwargs={'exception': Exception('Bad Request!')}),
        url(r'^403/$', default_views.permission_denied,
            kwargs={'exception': Exception('Permission Denied')}),
        url(r'^404/$', default_views.page_not_found,
            kwargs={'exception': Exception('Page not Found')}),
        url(r'^500/$', default_views.server_error),
    ] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

    if 'debug_toolbar' in settings.INSTALLED_APPS:
        import debug_toolbar
        urlpatterns.insert(0, url(r'^__debug__/', include(debug_toolbar.urls)))
